2021-05-06 Version: 2.0.4
- WhiteBoard SDK V2_0_4.

2021-04-21 Version: 2.0.3
- WhiteBoard SDK V2_0_3.

2021-04-15 Version: 2.0.2
- WhiteBoard SDK V2_0_2.

2021-03-30 Version: 1.0.1
- Generated python 2020-12-14 for rtc-white-board.

2021-01-26 Version: 1.0.0
- Generated python 2020-12-14 for rtc-white-board.

